summaryrefslogtreecommitdiffhomepage
path: root/packages/server/src/authentication/generateAuthenticationOptions.ts
diff options
context:
space:
mode:
authorJarrett Helton <jaydhelton@gmail.com>2021-08-24 15:59:38 -0400
committerJarrett Helton <jaydhelton@gmail.com>2021-08-24 15:59:38 -0400
commit900a701c6852719b805d470bdcb4447ea769e841 (patch)
treee614323cf30957ff29cdc011525ca0ebef115ec6 /packages/server/src/authentication/generateAuthenticationOptions.ts
parent1f0c326d0cc672de3f403f1c281257c39e3bc349 (diff)
refactor verified responses
Diffstat (limited to 'packages/server/src/authentication/generateAuthenticationOptions.ts')
-rw-r--r--packages/server/src/authentication/generateAuthenticationOptions.ts12
1 files changed, 6 insertions, 6 deletions
diff --git a/packages/server/src/authentication/generateAuthenticationOptions.ts b/packages/server/src/authentication/generateAuthenticationOptions.ts
index 35bf13e..f176835 100644
--- a/packages/server/src/authentication/generateAuthenticationOptions.ts
+++ b/packages/server/src/authentication/generateAuthenticationOptions.ts
@@ -8,7 +8,7 @@ import base64url from 'base64url';
import generateChallenge from '../helpers/generateChallenge';
-export type GenerateAssertionOptionsOpts = {
+export type GenerateAuthenticationOptionsOpts = {
allowCredentials?: PublicKeyCredentialDescriptor[];
challenge?: string | Buffer;
timeout?: number;
@@ -23,15 +23,15 @@ export type GenerateAssertionOptionsOpts = {
* @param allowCredentials Authenticators previously registered by the user, if any. If undefined
* the client will ask the user which credential they want to use
* @param challenge Random value the authenticator needs to sign and pass back
* user for assertion
* @param timeout How long (in ms) the user can take to complete assertion
* @param userVerification Set to `'discouraged'` when asserting as part of a 2FA flow, otherwise
* set to `'preferred'` or `'required'` as desired.
* @param extensions Additional plugins the authenticator or browser should use during assertion
* @param rpID Valid domain name (after `https://`)
*/
-export default function generateAssertionOptions(
- options: GenerateAssertionOptionsOpts = {},
+export default function generateAuthenticationOptions(
+ options: GenerateAuthenticationOptionsOpts = {},
): PublicKeyCredentialRequestOptionsJSON {
const {
allowCredentials,
@@ -23,15 +23,15 @@ export type GenerateAssertionOptionsOpts = {
* the client will ask the user which credential they want to use
* @param challenge Random value the authenticator needs to sign and pass back
- * user for assertion
- * @param timeout How long (in ms) the user can take to complete assertion
+ * user for authentication
+ * @param timeout How long (in ms) the user can take to complete authentication
* @param userVerification Set to `'discouraged'` when asserting as part of a 2FA flow, otherwise
* set to `'preferred'` or `'required'` as desired.
@@ -23,15 +23,15 @@ export type GenerateAssertionOptionsOpts = {
* @param userVerification Set to `'discouraged'` when asserting as part of a 2FA flow, otherwise
* set to `'preferred'` or `'required'` as desired.
- * @param extensions Additional plugins the authenticator or browser should use during assertion
+ * @param extensions Additional plugins the authenticator or browser should use during authentication
* @param rpID Valid domain name (after `https://`)
*/